@@ -4,12 +4,21 @@ from plone.testing import layered
 
 import doctest
 import os
+import six
+import re
 import unittest
 
 
 optionflags = doctest.ELLIPSIS | doctest.NORMALIZE_WHITESPACE
 
 
+class Py23DocChecker(doctest.OutputChecker):
+    def check_output(self, want, got, optionflags):
+        if six.PY2:
+            got = re.sub("u'(.*?)'", "'\\1'", got)
+        return doctest.OutputChecker.check_output(self, want, got, optionflags)
+
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTests(
@@ -18,6 +27,7 @@ def test_suite():
                 doctest.DocFileSuite(
                     os.path.join(os.path.pardir, 'schemaeditor.txt'),
                     optionflags=optionflags,
+                    checker=Py23DocChecker(),
                 ),
                 FUNCTIONAL_WIDGETS_TESTING,
             )
